@@ -1,22 +1,22 @@
-from coverage_strategies import CircleOutsideFromCornerAdjacentToIo_Strategy
-from coverage_strategies.CircleInsideFromCornerFarthestFromIo_Strategy import \
+from coverage_strategies.coverage_strategies import CircleOutsideFromCornerAdjacentToIo_Strategy
+from coverage_strategies.coverage_strategies.CircleInsideFromCornerFarthestFromIo_Strategy import \
     CircleInsideFromCornerFarthestFromIo_Strategy
-from coverage_strategies.CircleOutsideFromBoardCenter_Strategy import CircleOutsideFromBoardCenter_Strategy
-from coverage_strategies.CircleOutsideFromCornerFarthestFromIo_Strategy import \
+from coverage_strategies.coverage_strategies.CircleOutsideFromBoardCenter_Strategy import CircleOutsideFromBoardCenter_Strategy
+from coverage_strategies.coverage_strategies.CircleOutsideFromCornerFarthestFromIo_Strategy import \
     CircleOutsideFromCornerFarthestFromIo_Strategy
-from coverage_strategies.CircleOutsideFromIo_Strategy import CircleOutsideFromIo_Strategy
-from coverage_strategies.CoverByQuarters_Strategy import CoverByQuarters_Strategy
-from coverage_strategies.Entities import StrategyEnum
-from coverage_strategies.HorizontalCircularCoverage_Strategy import HorizontalCircularCoverage_Strategy
-from coverage_strategies.InterceptThenCopy_Strategy import InterceptThenCopy_Strategy
-from coverage_strategies.LCP_Strategy import LCP_Strategy
-from coverage_strategies.LongestToReach_Strategy import LongestToReach_Strategy
-from coverage_strategies.STC_Strategy import STC_Strategy
-from coverage_strategies.TrulyRandom_Strategy import TrulyRandomStrategy
-from coverage_strategies.VerticalCircularCoverage_Strategy import VerticalCircularCoverage_Strategy
-from coverage_strategies.VerticalCoverageFromCornerFarthestFromIo_Strategy import \
+from coverage_strategies.coverage_strategies.CircleOutsideFromIo_Strategy import CircleOutsideFromIo_Strategy
+from coverage_strategies.coverage_strategies.CoverByQuarters_Strategy import CoverByQuarters_Strategy
+from coverage_strategies.coverage_strategies.Entities import StrategyEnum
+from coverage_strategies.coverage_strategies.HorizontalCircularCoverage_Strategy import HorizontalCircularCoverage_Strategy
+from coverage_strategies.coverage_strategies.InterceptThenCopy_Strategy import InterceptThenCopy_Strategy
+from coverage_strategies.coverage_strategies.LCP_Strategy import LCP_Strategy
+from coverage_strategies.coverage_strategies.LongestToReach_Strategy import LongestToReach_Strategy
+from coverage_strategies.coverage_strategies.STC_Strategy import STC_Strategy
+from coverage_strategies.coverage_strategies.TrulyRandom_Strategy import TrulyRandomStrategy
+from coverage_strategies.coverage_strategies.VerticalCircularCoverage_Strategy import VerticalCircularCoverage_Strategy
+from coverage_strategies.coverage_strategies.VerticalCoverageFromCornerFarthestFromIo_Strategy import \
     VerticalCoverageFromCornerFarthestFromIo_Strategy
-from coverage_strategies.VerticalNonCircularCoverage_Strategy import VerticalNonCircularCoverage_Strategy
+from coverage_strategies.coverage_strategies.VerticalNonCircularCoverage_Strategy import VerticalNonCircularCoverage_Strategy
 
 
 def get_strategy_from_enum(strategy_enum: StrategyEnum):
